@@ -5,6 +5,8 @@ from . import views
 app_name = 'zenblog'
 
 urlpatterns = [
+    # robots.txt는 반드시 가장 먼저
+    path('robots.txt', views.robots),
     path('', views.home, name='home'),
     path('about/', views.about, name='about'),
     path('contact/', views.contact, name='contact'),
