@@ -3,6 +3,7 @@ from django.shortcuts import render
 from .models import Post, CATEGORY
 from django.views import generic
 from hitcount.views import HitCountDetailView
+from _data.blog import context as c
 from .forms import Search
 from util_demian import utils
 
@@ -35,6 +36,7 @@ def home(request):
 
 def about(request):
     context = {
+        'about': c['about'],
     }
     return render(request, 'zenblog/about.html', context)
 
